==> rehype-highlight-lines-3.0.0.tgz: package/README.md <==
![FreeSewing](https://static.freesewing.org/banner.png)
<p align='center'><a
  href="https://www.npmjs.com/package/rehype-highlight-lines"
  title="rehype-highlight-lines on NPM"
  ><img src="https://img.shields.io/npm/v/rehype-highlight-lines.svg"
  alt="rehype-highlight-lines on NPM"/>
  </a><a
  href="https://opensource.org/licenses/MIT"
  title="License: MIT"
  ><img src="https://img.shields.io/npm/l/rehype-highlight-lines.svg?label=License"
  alt="License: MIT"/>
  </a><a
  href="https://deepscan.io/dashboard#view=project&tid=2114&pid=2993&bid=23256"
  title="Code quality on DeepScan"
  ><img src="https://deepscan.io/api/teams/2114/projects/2993/branches/23256/badge/grade.svg"
  alt="Code quality on DeepScan"/>
  </a><a
  href="https://github.com/freesewing/freesewing/issues?q=is%3Aissue+is%3Aopen+label%3Apkg%3Arehype-highlight-lines"
  title="Open issues tagged pkg:rehype-highlight-lines"
  ><img src="https://img.shields.io/github/issues/freesewing/freesewing/pkg:rehype-highlight-lines.svg?label=Issues"
  alt="Open issues tagged pkg:rehype-highlight-lines"/>
  </a><a
  href="#contributors-"
  title="All Contributors"
  ><img src="https://img.shields.io/badge/all_contributors-111-pink.svg"
  alt="All Contributors"/>
  </a></p><p align='center'><a
  href="https://twitter.com/freesewing_org"
  title="Follow @freesewing_org on Twitter"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Follow%20us-blue.svg?logo=twitter&logoColor=white&logoWidth=15"
  alt="Follow @freesewing_org on Twitter"/>
  </a><a
  href="https://chat.freesewing.org"
  title="Chat with us on Discord"
  ><img src="https://img.shields.io/discord/698854858052075530?label=Chat%20on%20Discord"
  alt="Chat with us on Discord"/>
  </a><a
  href="https://freesewing.org/patrons/join"
  title="Become a FreeSewing Patron"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Support%20us-blueviolet.svg?logo=cash-app&logoColor=white&logoWidth=15"
  alt="Become a FreeSewing Patron"/>
  </a><a
  href="https://instagram.com/freesewing_org"
  title="Follow @freesewing_org on Twitter"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Follow%20us-E4405F.svg?logo=instagram&logoColor=white&logoWidth=15"
  alt="Follow @freesewing_org on Twitter"/>
  </a></p>

# rehype-highlight-lines

A Rehype plugin to add highlighted lines to code blocks




## What am I looking at? 🤔

This repository is the FreeSewing *monorepo* holding all FreeSewing's websites, documentation, designs, plugins, and other NPM packages.

This folder holds: rehype-highlight-lines

If you're not entirely sure what to do or how to start, type this command:

```
npm run tips
```

> If you don't want to set up a dev environment, you can run it in your browser:
> 
> [![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/freesewing/freesewing)
> 
> We recommend that you fork our repository and then 
> put `gitpod.io/#<entire-url-of-your-fork` into a browser 
> to start up a browser-based dev environment of your own.

## About FreeSewing 💀

Where the world of makers and developers collide, that's where you'll find FreeSewing.

If you're a maker, checkout [freesewing.org](https://freesewing.org/) where you can generate
sewing patterns adapted to your measurements.

If you're a developer, the FreeSewing documentation lives at [freesewing.dev](https://freesewing.dev/).
The FreeSewing [core library](https://freesewing.dev/reference/api/) is a *batteries-included* toolbox
for parametric design of sewing patterns. But FreeSewing also provides a range 
of [plugins](https://freesewing.dev/reference/plugins/) that further extend the 
functionality of the platform.

If you have NodeJS installed, you can try it right now by running:

```bash
npx create-freesewing-pattern
```

Getting started guides are available for:
- [Linux](https://freesewing.dev/tutorials/getting-started-linux/)
- [MacOS](https://freesewing.dev/tutorials/getting-started-mac/)
- [Windows](https://freesewing.dev/tutorials/getting-started-windows/)

The [pattern design tutorial](https://freesewing.dev/tutorials/pattern-design/) will
show you how to create your first parametric design.

## Support FreeSewing: Become a patron 🥰

FreeSewing is an open source project maintained by Joost De Cock and financially supported by the FreeSewing patrons.

If you feel FreeSewing is worthwhile, and you can spend a few coind without
hardship, then you should [join us and become a patron](https://freesewing.org/community/join).

## Links 👩‍💻

**Official channels**

 - 💻 Makers website: [FreeSewing.org](https://freesewing.org)
 - 💻 Developers website: [FreeSewing.dev](https://freesewing.dev)
 - ✅ [Support](https://github.com/freesewing/freesewing/issues/new/choose),
   [Issues](https://github.com/freesewing/freesewing/issues) &
   [Discussions](https://github.com/freesewing/freesewing/discussions) on
   [GitHub](https://github.com/freesewing/freesewing)

**Social media**

 - 🐦 Twitter: [@freesewing_org](https://twitter.com/freesewing_org)
 - 📷 Instagram: [@freesewing_org](https://instagram.com/freesewing_org)

**Places the FreeSewing community hangs out**

 - 💬 [Discord](https://discord.freesewing.org/)
 - 💬 [Facebook](https://www.facebook.com/groups/627769821272714/)
 - 💬 [Reddit](https://www.reddit.com/r/freesewing/)

## License: MIT 🤓

© [Joost De Cock](https://github.com/joostdecock).  
See [the license file](https://github.com/freesewing/freesewing/blob/develop/LICENSE) for details.

## Where to get help 🤯

For [Support](https://github.com/freesewing/freesewing/issues/new/choose),
please use the [Issues](https://github.com/freesewing/freesewing/issues) &
[Discussions](https://github.com/freesewing/freesewing/discussions) on
[GitHub](https://github.com/freesewing/freesewing).

==> rehype-highlight-lines-3.1.0-rc.0.tgz: package/README.md <==
![FreeSewing](https://static.freesewing.org/banner.png)
<p align='center'><a
  href="https://www.npmjs.com/package/rehype-highlight-lines"
  title="rehype-highlight-lines on NPM"
  ><img src="https://img.shields.io/npm/v/rehype-highlight-lines.svg"
  alt="rehype-highlight-lines on NPM"/>
  </a><a
  href="https://opensource.org/licenses/MIT"
  title="License: MIT"
  ><img src="https://img.shields.io/npm/l/rehype-highlight-lines.svg?label=License"
  alt="License: MIT"/>
  </a><a
  href="https://deepscan.io/dashboard#view=project&tid=2114&pid=2993&bid=23256"
  title="Code quality on DeepScan"
  ><img src="https://deepscan.io/api/teams/2114/projects/2993/branches/23256/badge/grade.svg"
  alt="Code quality on DeepScan"/>
  </a><a
  href="https://github.com/freesewing/freesewing/issues?q=is%3Aissue+is%3Aopen+label%3Apkg%3Arehype-highlight-lines"
  title="Open issues tagged pkg:rehype-highlight-lines"
  ><img src="https://img.shields.io/github/issues/freesewing/freesewing/pkg:rehype-highlight-lines.svg?label=Issues"
  alt="Open issues tagged pkg:rehype-highlight-lines"/>
  </a><a
  href="#contributors-"
  title="All Contributors"
  ><img src="https://img.shields.io/badge/all_contributors-119-pink.svg"
  alt="All Contributors"/>
  </a></p><p align='center'><a
  href="https://twitter.com/freesewing_org"
  title="Follow @freesewing_org on Twitter"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Follow%20us-blue.svg?logo=twitter&logoColor=white&logoWidth=15"
  alt="Follow @freesewing_org on Twitter"/>
  </a><a
  href="https://chat.freesewing.org"
  title="Chat with us on Discord"
  ><img src="https://img.shields.io/discord/698854858052075530?label=Chat%20on%20Discord"
  alt="Chat with us on Discord"/>
  </a><a
  href="https://freesewing.org/patrons/join"
  title="Become a FreeSewing Patron"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Support%20us-blueviolet.svg?logo=cash-app&logoColor=white&logoWidth=15"
  alt="Become a FreeSewing Patron"/>
  </a><a
  href="https://instagram.com/freesewing_org"
  title="Follow @freesewing_org on Twitter"
  ><img src="https://img.shields.io/badge/%F3%A0%80%A0-Follow%20us-E4405F.svg?logo=instagram&logoColor=white&logoWidth=15"
  alt="Follow @freesewing_org on Twitter"/>
  </a></p>

# rehype-highlight-lines

A Rehype plugin to add highlighted lines to code blocks




## What am I looking at? 🤔

This repository is the FreeSewing *monorepo* holding all FreeSewing's websites, documentation, designs, plugins, and other NPM packages.

This folder holds: rehype-highlight-lines

If you're not entirely sure what to do or how to start, type this command:

```
npm run tips
```

> If you don't want to set up a dev environment, you can run it in your browser:
> 
> [![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/freesewing/freesewing)
> 
> We recommend that you fork our repository and then 
> put `gitpod.io/#<entire-url-of-your-fork` into a browser 
> to start up a browser-based dev environment of your own.

## About FreeSewing 💀

Where the world of makers and developers collide, that's where you'll find FreeSewing.

If you're a maker, checkout [freesewing.org](https://freesewing.org/) where you can generate
sewing patterns adapted to your measurements.

If you're a developer, the FreeSewing documentation lives at [freesewing.dev](https://freesewing.dev/).
The FreeSewing [core library](https://freesewing.dev/reference/api/) is a *batteries-included* toolbox
for parametric design of sewing patterns. But FreeSewing also provides a range 
of [plugins](https://freesewing.dev/reference/plugins/) that further extend the 
functionality of the platform.

If you have NodeJS installed, you can try it right now by running:

```bash
npx create-freesewing-pattern
```

Getting started guides are available for:
- [Linux](https://freesewing.dev/tutorials/getting-started-linux/)
- [MacOS](https://freesewing.dev/tutorials/getting-started-mac/)
- [Windows](https://freesewing.dev/tutorials/getting-started-windows/)

The [pattern design tutorial](https://freesewing.dev/tutorials/pattern-design/) will
show you how to create your first parametric design.

## Support FreeSewing: Become a patron 🥰

FreeSewing is an open source project maintained by Joost De Cock and financially supported by the FreeSewing patrons.

If you feel FreeSewing is worthwhile, and you can spend a few coins without
hardship, then you should [join us and become a patron](https://freesewing.org/community/join).

## Links 👩‍💻

**Official channels**

 - 💻 Makers website: [FreeSewing.org](https://freesewing.org)
 - 💻 Developers website: [FreeSewing.dev](https://freesewing.dev)
 - ✅ [Support](https://github.com/freesewing/freesewing/issues/new/choose),
   [Issues](https://github.com/freesewing/freesewing/issues) &
   [Discussions](https://github.com/freesewing/freesewing/discussions) on
   [GitHub](https://github.com/freesewing/freesewing)

**Social media**

 - 🐦 Twitter: [@freesewing_org](https://twitter.com/freesewing_org)
 - 📷 Instagram: [@freesewing_org](https://instagram.com/freesewing_org)

**Places the FreeSewing community hangs out**

 - 💬 [Discord](https://discord.freesewing.org/)
 - 💬 [Facebook](https://www.facebook.com/groups/627769821272714/)
 - 💬 [Reddit](https://www.reddit.com/r/freesewing/)

## License: MIT 🤓

© [Joost De Cock](https://github.com/joostdecock).  
See [the license file](https://github.com/freesewing/freesewing/blob/develop/LICENSE) for details.

## Where to get help 🤯

For [Support](https://github.com/freesewing/freesewing/issues/new/choose),
please use the [Issues](https://github.com/freesewing/freesewing/issues) &
[Discussions](https://github.com/freesewing/freesewing/discussions) on
[GitHub](https://github.com/freesewing/freesewing).
